@@ -9,7 +9,7 @@ from enum import Enum
 from typing import List, Dict, Optional
 
 from gateways.common.cs18_api_classes import AccessLink, TerraformModuleDescriptor, \
-    TerraformModuleInput, TerraformModuleComputeService
+    TerraformModuleInput, TerraformModuleComputeService, TerraformModuleOutput
 from gateways.common.cs18_api_errors import SandboxError, Error
 
 
@@ -475,24 +475,50 @@ class SandboxOutput:
 
 class ServiceTfProgressResponse:
     def __init__(self,
+                 tf_tagging_status: str,
+                 tf_init_status: str,
                  tf_plan_status: str,
                  tf_apply_status: str,
                  tf_destroy_status: str):
+        self.tf_tagging_status = tf_tagging_status
+        self.tf_init_status = tf_init_status
         self.tf_plan_status = tf_plan_status
         self.tf_apply_status = tf_apply_status
         self.tf_destroy_status = tf_destroy_status
 
 
+class ServiceTfLogInfo:
+    def __init__(self,
+                 location: str):
+        self.location = location
+
+
+class ServiceTfLogsResponse:
+    def __init__(self,
+                 tf_tagging: ServiceTfLogInfo= None,
+                 tf_init: ServiceTfLogInfo = None,
+                 tf_plan: ServiceTfLogInfo = None,
+                 tf_apply: ServiceTfLogInfo = None,
+                 tf_destroy: ServiceTfLogInfo = None):
+        self.tf_tagging = tf_tagging
+        self.tf_init = tf_init
+        self.tf_plan = tf_plan
+        self.tf_apply = tf_apply
+        self.tf_destroy = tf_destroy
+
+
 class ServiceResponse:
     def __init__(self,
                  name: str,
                  service_type: str,
                  status: str,
-                 progress: ServiceTfProgressResponse):
+                 progress: ServiceTfProgressResponse,
+                 logs: ServiceTfLogsResponse = None):
         self.name = name
         self.type = service_type
         self.status = status
         self.progress = progress
+        self.logs = logs
 
 
 class SandboxResponse(SandboxResponseBase):
@@ -971,12 +997,14 @@ class RepositoryProviderResponse:
 
 
 class AccountRepositoryResponse:
-    def __init__(self, repository_id: str, name: str, provider_id: str, allow_sharing: str, open_access: str,
-                 account_id: str, is_valid: bool, connection_details, repository_url: str, errors: List[Error]):
+    def __init__(self, repository_id: str, name: str, provider_id: str, provider_name: str, allow_sharing: str,
+                 open_access: str, account_id: str, is_valid: bool, connection_details, repository_url: str,
+                 errors: List[Error]):
         self.repository_url = repository_url
         self.repository_id = repository_id
         self.name = name
         self.provider_id = provider_id
+        self.provider_name = provider_name
         self.allow_sharing = allow_sharing
         self.open_access = open_access
         self.account_id = account_id
@@ -1205,17 +1233,42 @@ class CreateAccountFinalizeResponse:
         self.last_name = last_name
 
 
+class CustomTagResponse:
+    def __init__(self,
+                 name: str,
+                 value: str,
+                 scope: str,
+                 possible_values: [],
+                 description: str,
+                 modified_by: str,
+                 last_modified: datetime,
+                 created_by: str,
+                 created_date: datetime,
+                 ):
+        self.name = name
+        self.value = value
+        self.scope = scope
+        self.possible_values = possible_values
+        self.description = description
+        self.modified_by = modified_by
+        self.last_modified = last_modified
+        self.created_date = created_date
+        self.created_by = created_by
+
+        
 class TerraformModuleDescriptorResponse(TerraformModuleDescriptor):
     def __init__(self, module_name: str = None, module_repo_name: str = None, module_root_path: str = None,
                  description: str = None, terraform_version: str = None, enable_auto_tagging: bool = None,
                  exclude_from_tagging: List[str] = None, inputs: List[TerraformModuleInput] = None,
-                 outputs: List[TerraformModuleInput] = None,
+                 outputs: List[TerraformModuleOutput] = None,
                  compute_services: List[TerraformModuleComputeService] = None,
                  allowed_spaces: List[str] = None, modified_by: str = None, last_modified: datetime = None,
                  created_by: str = None, created_date: datetime = None):
-        super().__init__(module_name, module_repo_name, module_root_path, description,
-                         terraform_version, enable_auto_tagging, exclude_from_tagging,
-                         inputs, outputs, compute_services, allowed_spaces)
+        super().__init__(module_name=module_name, module_repo_name=module_repo_name, module_root_path=module_root_path,
+                         description=description, terraform_version=terraform_version,
+                         enable_auto_tagging=enable_auto_tagging, exclude_from_tagging=exclude_from_tagging,
+                         inputs=inputs, outputs=outputs, compute_services=compute_services,
+                         allowed_spaces=allowed_spaces)
         self.created_date = created_date
         self.created_by = created_by
         self.last_modified = last_modified
